bayespy.inference.vmp.transformations.RotateGaussianARD.get_bound_terms
=======================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianARD.get_bound_terms